@@ -308,7 +308,14 @@ class State(CP.AbstractState):
         viscosity : pint.Quantity
             Viscosity (pascal second)
         """
-        viscosity = Q_(super().viscosity(), "pascal second")
+        try:
+            viscosity = Q_(super().viscosity(), "pascal second")
+        except ValueError:
+            # handle error for cubic eos such as PR, SRK etc.
+            dummy_state = self.define(
+                p=self.p(), T=self.T(), fluid=self.fluid, EOS="REFPROP"
+            )
+            viscosity = Q_(super(State, dummy_state).viscosity(), "pascal second")
         if units:
             viscosity = viscosity.to(units)
         return viscosity
@@ -547,7 +554,10 @@ class State(CP.AbstractState):
                     super(State, self).update(CP.PT_INPUTS, p.magnitude, T)
                     return self.smass() - s.magnitude
 
-                newton(objective, x0=self.T().m)
+                T0 = self.T().m
+                if T0 == float("-inf"):
+                    T0 = 300
+                newton(objective, x0=T0)
         elif rho is not None and s is not None:
             super().update(CP.DmassSmass_INPUTS, rho.magnitude, s.magnitude)
         elif rho is not None and T is not None:
